@@ -13,14 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
+from designate.objects import fields
 
 
+@base.DesignateRegistry.register
 class Quota(base.DictObjectMixin, base.PersistentObjectMixin,
             base.DesignateObject):
-    FIELDS = {
-        'tenant_id': {},
-        'resource': {},
-        'hard_limit': {}
+    fields = {
+        'tenant_id': fields.AnyField(nullable=True),
+        'resource': fields.AnyField(nullable=True),
+        'hard_limit': fields.AnyField(nullable=True)
     }
 
     STRING_KEYS = [
@@ -28,9 +30,14 @@ class Quota(base.DictObjectMixin, base.PersistentObjectMixin,
     ]
 
 
+@base.DesignateRegistry.register
 class QuotaList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = Quota
 
+    fields = {
+        'objects': fields.ListOfObjectsField('Quota'),
+    }
+
     @classmethod
     def from_dict(cls, _dict):
 
